/*
    Freud - a standalone C++ port of the Emacs Psychiatrist
    Copyright (C) 2002  Markus Triska

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    You can contact me via triska@gmx.at
*/

#include <map>
#include <string>
#include <vector>
#include <algorithm>

class WordTypeDeterminer
{
public:
	WordTypeDeterminer() { }
	WordTypeDeterminer& add(const std::string &word, const std::string &type) {
		wordtypes[type].push_back(word);
		return *this;
	}

	bool isType(const std::string &word, const std::string &type) {
		if (wordtypes.find(type) == wordtypes.end()) return false;
		std::vector<std::string> v = wordtypes[type];
		return (std::find(v.begin(), v.end(), word) != v.end());
	}

	bool isNoun(const std::string &);
	bool isModifier(const std::string &);
	bool isAdjective(const std::string &);
	bool isAdverb(const std::string &);

private:
	std::map<std::string, std::vector<std::string> > wordtypes;
};


// GCC 2.95.3 does not implement "export template".
#include <sstream>
template<class T> T for_each_word(const std::string &s, T t)
{
	std::istringstream ist(s);
	while (true) {
		std::string oneword;
		ist >> oneword;
		if (oneword == "") break;
		t(oneword);
	}
	return t;
}

